@@ -273,3 +273,42 @@ class QuickbooksCore(SitesCore):
                                         )
 
         return True, invoice_date, invoice_number
+
+    def open_customers_page(self) -> None:
+        """
+        Open Customers page
+        """
+        self.browser.go_to(f'{self.base_url}/app/homepage')
+        self.click_bunch_of_elements([
+            '//span[text()="Sales"]/..',
+            '//a[text()="Customers"]'
+        ])
+        self.wait_element('//li[contains(@class, "active")]/a[text()="Customers"]', 5, False)
+
+    def add_new_customer(self, customer_name: str, first_name: str, last_name: str, email: str) -> bool:
+        self.open_customers_page()
+
+        self.wait_and_click('//span[text()="New customer"]/..')
+        self.wait_element('//input[@name="companyName"]')
+
+        self.browser.input_text('//input[@name="companyName"]', customer_name)
+        self.browser.input_text('//input[@name="displayName"]', customer_name)
+        self.browser.input_text('//input[@name="firstName"]', first_name)
+        self.browser.input_text('//input[@name="lastName"]', last_name)
+        self.browser.input_text('//input[@name="email"]', email)
+
+        self.browser.click_element_when_visible('//button[@data-automation-id="saveButton"]')
+        self.wait_element(f'//p[@data-qbo-bind="text: companyName" and text()="{customer_name}"]', 15, False)
+        if self.does_element_displayed(f'//p[@data-qbo-bind="text: companyName" and text()="{customer_name}"]'):
+            return True
+        else:
+            error: str = ''
+            for alert in self.browser.find_elements('//div[@class="alert-content"]'):
+                if alert.is_displayed():
+                    error: str = alert.text
+                    print(error)
+                    break
+            self.browser.click_element_when_visible('//button[@data-automation-id="customerCancelBtn"]')
+            if 'Please use a different name' in error:
+                return True
+        return False
